@@ -1,6 +1,6 @@
 from .controller import ShieldController
 from .exception import AutomationShieldException
-from .shields import AeroShield, FloatShield, MagnetoShield, DummyShield
+from .shields import AeroShield, AeroShieldMimic, FloatShield, MagnetoShield, StateSpaceShield
 
 
 # install arduino-cli if not present
