@@ -10,25 +10,25 @@ class FloatShield(BaseShield):
     Interface:
         * Actuator input should be provided in percent by default.
         * Potentiometer is provided in percent by default.
-        * Sensor values are provided in millimeters from the bottom of the tube.
+        * Sensor values are provided in millimetres from the bottom of the tube.
     """
     script = "floatshield"
     shield_id = "FL"
 
     actuator_bits = 12
+    potentiometer_bits = 10
+    sensor_bits = 12
 
-    class PlotInfo:
+    class PlotInfo(BaseShield.PlotInfo):
         sensor_unit = "mm"
-        sensor_type = "Distance"
+        sensor_type = "Height"
         sensor_min = 0
         sensor_max = 320
 
     def calibrate_sensor_reading(self, sensor: int) -> int:
-        """Calibrate sensor reading. 0 is taken as the ball being at the bottome of the tube.
+        """Calibrate sensor reading. 0 is taken as the ball being at the bottom of the tube.
 
         :param sensor: Raw sensor value.
-        :type sensor: int
         :return: Calibrate sensor value.
-        :rtype: int
         """
         return - super().calibrate_sensor_reading(sensor)
